@@ -1,9 +1,5 @@
 /*
- * $Id: libcap.h,v 1.2.2.2 1999/05/01 23:33:32 morgan Exp $
- *
- * Copyright (c) 1997 Andrew G Morgan <morgan@linux.kernel.org>
- *
- * See end of file for Log.
+ * Copyright (c) 1997 Andrew G Morgan <morgan@kernel.org>
  *
  * This file contains internal definitions for the various functions in
  * this small capability library.
@@ -12,7 +8,6 @@
 #ifndef LIBCAP_H
 #define LIBCAP_H
 
-#include <sys/types.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -39,38 +34,21 @@
  * to processes.
  */
 
+#define CAP_T_MAGIC 0xCA90D0
 struct _cap_struct {
-    unsigned features;
     struct __user_cap_header_struct head;
     struct __user_cap_data_struct set;
 };
 
-/*
- * Some magic cookies identifying capability objects that this library
- * maintains.
- */
-
-/* this is stored immediately preceeding the capability structure */
-#define CAP_T_MAGIC (0xCA90D1 ^ _LINUX_CAPABILITY_VERSION)
-
-/* this is stored immediately preceeding a string produced by
-   cap_to_text */
-#define CAP_S_MAGIC (0xCA95DA ^ _LINUX_CAPABILITY_VERSION)
-
-/*
- * 'feature' set of methods supported by kernel
- */
-
-#define CAP_FEATURE_PROC    0x00000001  /* added 0x19980330 */
-#define CAP_FEATURE_FILE    0x00000002  /* added 0x19990414 */
+/* string magic for cap_free */
+#define CAP_S_MAGIC 0xCA95D0
 
 /*
  * Do we match the local kernel?
  */
 
 #if !defined(_LINUX_CAPABILITY_VERSION) || \
-            ((_LINUX_CAPABILITY_VERSION != 0x19980330) \
-	     && (_LINUX_CAPABILITY_VERSION != 0x19990414))
+            (_LINUX_CAPABILITY_VERSION != 0x19980330)
 
 # error "Kernel <linux/capability.h> does not match library"
 # error "file "libcap.h" --> fix and recompile libcap"
@@ -112,7 +90,7 @@ typedef struct {
 }
 # define _cap_debugcap(s, c) \
     fprintf(stderr, __FUNCTION__ "(" __FILE__ ":%d): " s \
-       "%08x\n", __LINE__, *c)
+       "%08x\n", __LINE__, *(c))
 
 #else /* !DEBUG */
 
@@ -121,6 +99,8 @@ typedef struct {
 
 #endif /* DEBUG */
 
+extern char *_libcap_strdup(const char *text);
+
 /*
  * These are semi-public prototypes, they will only be defined in
  * <sys/capability.h> if _POSIX_SOURCE is not #define'd, so we
@@ -132,40 +112,4 @@ extern int capget(cap_user_header_t header, const cap_user_data_t data);
 extern int capgetp(pid_t pid, cap_t cap_d);
 extern int capsetp(pid_t pid, cap_t cap_d);
 
-extern char *_libcap_strdup(const char *);
-extern void _libcap_establish_api(void);
-extern unsigned int _libcap_kernel_version;
-extern unsigned int _libcap_kernel_features;
-
 #endif /* LIBCAP_H */
-
-/*
- * $Log: libcap.h,v $
- * Revision 1.2.2.2  1999/05/01 23:33:32  morgan
- * made cap_free responsible for liberating strings returned by cap_to_text
- *
- * Revision 1.2.2.1  1999/04/23 06:16:31  morgan
- * added support for revised kernel interface (with file cap support)
- *
- * Revision 1.2  1999/04/17 23:25:10  morgan
- * fixes from peeterj
- *
- * Revision 1.1.1.1  1999/04/17 22:16:31  morgan
- * release 1.0 of libcap
- *
- * Revision 1.5  1998/06/08 00:15:28  morgan
- * accommodate alpha (glibc?)
- *
- * Revision 1.4  1998/06/07 15:58:23  morgan
- * accommodate real kernel header files :*)
- *
- * Revision 1.3  1998/05/24 22:54:09  morgan
- * updated for 2.1.104
- *
- * Revision 1.2  1997/04/28 00:57:11  morgan
- * zefram's replacement file with a number of bug fixes from AGM
- *
- * Revision 1.1  1997/04/21 04:32:52  morgan
- * Initial revision
- *
- */
